
## v0.0.3
- Refactor `do_linear_regression()`, so that it takes `&[f64]` as input, as opposed to `&[(f64, f64)]`.
- Use Rust 1.92.

## v0.0.2
- Move the code for Python bindings into lib.rs.

## v0.0.1
- Initial release.